@@ -172,19 +172,20 @@ struct bmp_progressive_state {
 };
 
 gpointer
-image_begin_load(ModulePreparedNotifyFunc prepared_func,
-		 ModuleUpdatedNotifyFunc updated_func,
-		 ModuleFrameDoneNotifyFunc frame_done_func,
-		 ModuleAnimationDoneNotifyFunc anim_done_func,
-		 gpointer user_data);
-void image_stop_load(gpointer data);
-gboolean image_load_increment(gpointer data, guchar * buf, guint size);
+gdk_pixbuf__bmp_image_begin_load(ModulePreparedNotifyFunc prepared_func,
+				 ModuleUpdatedNotifyFunc updated_func,
+				 ModuleFrameDoneNotifyFunc frame_done_func,
+				 ModuleAnimationDoneNotifyFunc anim_done_func,
+				 gpointer user_data);
+
+void gdk_pixbuf__bmp_image_stop_load(gpointer data);
+gboolean gdk_pixbuf__bmp_image_load_increment(gpointer data, guchar * buf, guint size);
 
 
 
 /* Shared library entry point --> This should be removed when
    generic_image_load enters gdk-pixbuf-io. */
-GdkPixbuf *image_load(FILE * f)
+GdkPixbuf *gdk_pixbuf__bmp_image_load(FILE * f)
 {
 	guchar *membuf;
 	size_t length;
@@ -192,7 +193,7 @@ GdkPixbuf *image_load(FILE * f)
 
 	GdkPixbuf *pb;
 
-	State = image_begin_load(NULL, NULL, NULL, NULL, NULL);
+	State = gdk_pixbuf__bmp_image_begin_load(NULL, NULL, NULL, NULL, NULL);
 	membuf = g_malloc(4096);
 
 	g_assert(membuf != NULL);
@@ -201,7 +202,7 @@ GdkPixbuf *image_load(FILE * f)
 	while (feof(f) == 0) {
 		length = fread(membuf, 1, 4096, f);
 		if (length > 0)
-			(void) image_load_increment(State, membuf, length);
+			(void) gdk_pixbuf__bmp_image_load_increment(State, membuf, length);
 
 	}
 	g_free(membuf);
@@ -210,7 +211,7 @@ GdkPixbuf *image_load(FILE * f)
 
 	pb = State->pixbuf;
 
-	image_stop_load(State);
+	gdk_pixbuf__bmp_image_stop_load(State);
 	return pb;
 }
 
@@ -305,11 +306,11 @@ static void DecodeHeader(unsigned char *BFH, unsigned char *BIH,
  */
 
 gpointer
-image_begin_load(ModulePreparedNotifyFunc prepared_func,
-		 ModuleUpdatedNotifyFunc updated_func,
-		 ModuleFrameDoneNotifyFunc frame_done_func,
-		 ModuleAnimationDoneNotifyFunc anim_done_func,
-		 gpointer user_data)
+gdk_pixbuf__bmp_image_begin_load(ModulePreparedNotifyFunc prepared_func,
+				 ModuleUpdatedNotifyFunc updated_func,
+				 ModuleFrameDoneNotifyFunc frame_done_func,
+				 ModuleAnimationDoneNotifyFunc anim_done_func,
+				 gpointer user_data)
 {
 	struct bmp_progressive_state *context;
 
@@ -347,7 +348,7 @@ image_begin_load(ModulePreparedNotifyFunc prepared_func,
  *
  * free context, unref gdk_pixbuf
  */
-void image_stop_load(gpointer data)
+void gdk_pixbuf__bmp_image_stop_load(gpointer data)
 {
 	struct bmp_progressive_state *context =
 	    (struct bmp_progressive_state *) data;
@@ -658,7 +659,7 @@ void DoCompressedByte(struct bmp_progressive_state *context, guchar ** buf,
  *
  * append image data onto inrecrementally built output image
  */
-gboolean image_load_increment(gpointer data, guchar * buf, guint size)
+gboolean gdk_pixbuf__bmp_image_load_increment(gpointer data, guchar * buf, guint size)
 {
 	struct bmp_progressive_state *context =
 	    (struct bmp_progressive_state *) data;
