@@ -123,6 +123,8 @@ struct _GifContext
 	int frame_len;
 	int frame_height;
 	int frame_interlace;
+	int x_offset;
+	int y_offset;
 
 	/* Static read only */
 	FILE *file;
@@ -352,7 +354,7 @@ gif_get_extension (GifContext *context)
 				if ((context->block_buf[0] & 0x1) != 0) {
 					context->gif89.transparent = context->block_buf[3];
 				} else {
-					context->gif89.transparent = FALSE;
+					context->gif89.transparent = -1;
 				}
 			}
 
@@ -605,7 +607,7 @@ gif_fill_in_pixels (GifContext *context, guchar *dest, gint offset, guchar v)
 {
 	guchar *pixel = NULL;
 
-	if (context->gif89.transparent) {
+	if (context->gif89.transparent != -1) {
 		pixel = dest + (context->draw_ypos + offset) * gdk_pixbuf_get_rowstride (context->pixbuf) + context->draw_xpos * 4;
 		*pixel = context->color_map [0][(guchar) v];
 		*(pixel+1) = context->color_map [1][(guchar) v];
@@ -664,9 +666,8 @@ gif_get_lzw (GifContext *context)
 	gint v;
 
 	if (context->pixbuf == NULL) {
-		g_print ("making a new pixbuf\n");
 		context->pixbuf = gdk_pixbuf_new (ART_PIX_RGB,
-						  context->gif89.transparent,
+						  context->gif89.transparent != -1,
 						  8,
 						  context->width,
 						  context->height);
@@ -675,8 +676,8 @@ gif_get_lzw (GifContext *context)
 			(* context->prepare_func) (context->pixbuf, context->user_data);
 		if (context->animation || context->frame_done_func) {
 			context->frame = g_new (GdkPixbufFrame, 1);
-			context->frame->x_offset = 0;
-			context->frame->y_offset = 0;
+			context->frame->x_offset = context->x_offset;
+			context->frame->y_offset = context->y_offset;;
 			context->frame->delay_time = context->gif89.delay_time;
 			switch (context->gif89.disposal) {
 			case 0:
@@ -713,7 +714,7 @@ gif_get_lzw (GifContext *context)
 		}
 		bound_flag = TRUE;
 
-		if (context->gif89.transparent) {
+		if (context->gif89.transparent != -1) {
 			temp = dest + context->draw_ypos * gdk_pixbuf_get_rowstride (context->pixbuf) + context->draw_xpos * 4;
 			*temp = context->color_map [0][(guchar) v];
 			*(temp+1) = context->color_map [1][(guchar) v];
@@ -935,10 +936,9 @@ gif_get_frame_info (GifContext *context)
 	/* Okay, we got all the info we need.  Lets record it */
 	context->frame_len = LM_to_uint (buf[4], buf[5]);
 	context->frame_height = LM_to_uint (buf[6], buf[7]);
-	if (context->frame) {
-		context->frame->x_offset = LM_to_uint (buf[0], buf[1]);
-		context->frame->y_offset = LM_to_uint (buf[2], buf[3]);
-	}
+	context->x_offset = LM_to_uint (buf[0], buf[1]);
+	context->y_offset = LM_to_uint (buf[2], buf[3]);
+
 	if (context->frame_height > context->height) {
 		/* we don't want to resize things.  So we exit */
 		context->state = GIF_DONE;
@@ -1064,6 +1064,7 @@ new_context (void)
 	GifContext *context;
 
 	context = g_new0 (GifContext, 1);
+
 	context->pixbuf = NULL;
 	context->file = NULL;
 	context->state = GIF_START;
@@ -1078,11 +1079,12 @@ new_context (void)
 	context->gif89.delay_time = -1;
 	context->gif89.input_flag = -1;
 	context->gif89.disposal = -1;
+
 	return context;
 }
 /* Shared library entry point */
 GdkPixbuf *
-image_load (FILE *file)
+gdk_pixbuf__gif_image_load (FILE *file)
 {
 	GifContext *context;
 
@@ -1097,11 +1099,11 @@ image_load (FILE *file)
 }
 
 gpointer
-image_begin_load (ModulePreparedNotifyFunc prepare_func,
-		  ModuleUpdatedNotifyFunc update_func,
-		  ModuleFrameDoneNotifyFunc frame_done_func,
-		  ModuleAnimationDoneNotifyFunc anim_done_func,
-		  gpointer user_data)
+gdk_pixbuf__gif_image_begin_load (ModulePreparedNotifyFunc prepare_func,
+				  ModuleUpdatedNotifyFunc update_func,
+				  ModuleFrameDoneNotifyFunc frame_done_func,
+				  ModuleAnimationDoneNotifyFunc anim_done_func,
+				  gpointer user_data)
 {
 	GifContext *context;
 
@@ -1119,7 +1121,7 @@ image_begin_load (ModulePreparedNotifyFunc prepare_func,
 }
 
 void
-image_stop_load (gpointer data)
+gdk_pixbuf__gif_image_stop_load (gpointer data)
 {
 	GifContext *context = (GifContext *) data;
 
@@ -1134,7 +1136,7 @@ image_stop_load (gpointer data)
 }
 
 gboolean
-image_load_increment (gpointer data, guchar *buf, guint size)
+gdk_pixbuf__gif_image_load_increment (gpointer data, guchar *buf, guint size)
 {
 	gint retval;
 	GifContext *context = (GifContext *) data;
@@ -1192,7 +1194,7 @@ image_load_increment (gpointer data, guchar *buf, guint size)
 }
 
 GdkPixbufAnimation *
-image_load_animation (FILE *file)
+gdk_pixbuf__gif_image_load_animation (FILE *file)
 {
 	GifContext *context;
 
